body:-webkit-scrollbar-track,
.dropdown-fontname:-webkit-scrollbar-track {
    /* margin-top: 5px; */
    -webkit-box-shadow: inset 0 0 6px rgba(0, 0, 0, 0);
    background-color: rgba(0, 0, 0, 0);
}

body::-webkit-scrollbar,
.dropdown-fontname::-webkit-scrollbar {
    width: 10px;
    height: 10px;
}

body::-webkit-scrollbar:horizontal,
.dropdown-fontname::-webkit-scrollbar:horizontal {
    height: 10px
}

body::-webkit-scrollbar-thumb,
.dropdown-fontname::-webkit-scrollbar-thumb {
    border-radius: 5px;
    border-style: dashed;
    background-color: rgba(255, 255, 255, 0.0);
    border-color: transparent;
    border-width: 2px;
    background-clip: padding-box;
}

body::-webkit-scrollbar-thumb:hover,
.dropdown-fontname::-webkit-scrollbar-thumb:hover {
    border-width: 1px;
    background-color: rgba(0, 0, 0, .5);
    border-radius: 5px;
    border-color: rgba(0, 0, 0, 0.05);
}

body::-webkit-scrollbar-thumb:active,
.dropdown-fontname::-webkit-scrollbar-thumb:active {
    border-width: 1px;
    background-color: rgba(0, 0, 0, .4);
    border-radius: 5px;
    border-color: rgba(0, 0, 0, 0.05);
    /* -webkit-box-shadow:inset 0 0 6px rgba(83,96,118,.6) */
}

body::-webkit-scrollbar-corner,
.dropdown-fontname::-webkit-scrollbar-corner {
    background: transparent;
    opacity: 0;
    display: none;
}
.dropdown-fontname::-webkit-scrollbar-track-piece {
    margin: 5px 0;
  }